==> sdk-test-domain-0.0.196-sources.jar: com/xforceplus/sdktest/metadata/PageMeta.java <==
package com.xforceplus.sdktest.metadata;

/**
 *
 * @author ultraman
 * @since 2021-05-20
 */

public class PageMeta {
    public interface Company {
        static String code() {
            return "company";
        }
        static String name() {
            return "公司";
        }
    }
    public interface RouteManangement {
        static String code() {
            return "routeManangement";
        }
        static String name() {
            return "路由配置";
        }
    }
    public interface Import {
        static String code() {
            return "import";
        }
        static String name() {
            return "导入测试";
        }
    }
    public interface ActionTrail {
        static String code() {
            return "actionTrail";
        }
        static String name() {
            return "行为审计";
        }
    }
    public interface ObjectIndex {
        static String code() {
            return "objectIndex";
        }
        static String name() {
            return "对象主键管理";
        }
    }
    public interface Relationtest {
        static String code() {
            return "relationtest";
        }
        static String name() {
            return "个人公司管理";
        }
    }
    public interface Mobiletest {
        static String code() {
            return "mobiletest";
        }
        static String name() {
            return "移动端测试";
        }
    }
    public interface Dperson {
        static String code() {
            return "dperson";
        }
        static String name() {
            return "dperson";
        }
    }
    public interface Testtenant {
        static String code() {
            return "testtenant";
        }
        static String name() {
            return "testtenant";
        }
    }
    public interface UltramanPerson {
        static String code() {
            return "ultramanPerson";
        }
        static String name() {
            return "奥特曼定制演示";
        }
    }
    public interface AppManage {
        static String code() {
            return "appManage";
        }
        static String name() {
            return "应用管理";
        }
    }
    public interface BaseAppManage {
        static String code() {
            return "baseAppManage";
        }
        static String name() {
            return "奥特曼应用管理";
        }
    }
}

==> sdk-test-domain-0.0.228-sources.jar: com/xforceplus/sdktest/metadata/PageMeta.java <==
package com.xforceplus.sdktest.metadata;

/**
 *
 * @author ultraman
 * @since 2021-06-13
 */

public class PageMeta {
    public interface Company {
        static String code() {
            return "company";
        }
        static String name() {
            return "公司";
        }
    }
    public interface RouteManangement {
        static String code() {
            return "routeManangement";
        }
        static String name() {
            return "路由配置";
        }
    }
    public interface Import {
        static String code() {
            return "import";
        }
        static String name() {
            return "导入测试";
        }
    }
    public interface ActionTrail {
        static String code() {
            return "actionTrail";
        }
        static String name() {
            return "行为审计";
        }
    }
    public interface ObjectIndex {
        static String code() {
            return "objectIndex";
        }
        static String name() {
            return "对象主键管理";
        }
    }
    public interface Relationtest {
        static String code() {
            return "relationtest";
        }
        static String name() {
            return "个人公司管理";
        }
    }
    public interface Mobiletest {
        static String code() {
            return "mobiletest";
        }
        static String name() {
            return "移动端测试";
        }
    }
    public interface Dperson {
        static String code() {
            return "dperson";
        }
        static String name() {
            return "dperson";
        }
    }
    public interface Testtenant {
        static String code() {
            return "testtenant";
        }
        static String name() {
            return "testtenant";
        }
    }
    public interface UltramanPerson {
        static String code() {
            return "ultramanPerson";
        }
        static String name() {
            return "奥特曼定制演示";
        }
    }
    public interface AppManage {
        static String code() {
            return "appManage";
        }
        static String name() {
            return "应用管理";
        }
    }
    public interface BaseAppManage {
        static String code() {
            return "baseAppManage";
        }
        static String name() {
            return "奥特曼应用管理";
        }
    }
    public interface FiveAppManage {
        static String code() {
            return "fiveAppManage";
        }
        static String name() {
            return "五层应用管理";
        }
    }
    public interface Air {
        static String code() {
            return "air";
        }
        static String name() {
            return "测试关系对象导出能否带主对象字段";
        }
    }
    public interface ComponentMa {
        static String code() {
            return "componentMa";
        }
        static String name() {
            return "组件管理-业务主键";
        }
    }
    public interface InvManage {
        static String code() {
            return "invManage";
        }
        static String name() {
            return "发票信息测试页面";
        }
    }
}
